@@ -87,6 +87,8 @@ pub use dimension::{
     IntoDimension,
     RemoveAxis,
     Axis,
+    Axes,
+    AxisDescription,
 };
 pub use dimension::dim::*;
 
@@ -112,6 +114,7 @@ pub use stacking::stack;
 
 pub use shape_builder::{ ShapeBuilder};
 
+#[macro_use] mod macro_utils;
 mod aliases;
 mod arraytraits;
 #[cfg(feature = "serde")]
